==> opennebula_3.2.1.orig.tar.gz: opennebula-3.2.1/src/sunstone/public/locale/en_US/en_US.js <==
//Translated by
lang="en_US"
datatable_lang=""
locale={
    "Accept (default)":"",
    "Acl":"",
    "ACL Rules":"",
    "ACLs":"",
    "ACL String preview":"",
    "ACPI":"",
    "Add":"",
    "Add context variables":"",
    "Add custom variables":"",
    "Add disk/image":"",
    "Add disks/images":"",
    "Add Graphics":"",
    "Add Hypervisor raw options":"",
    "Add inputs":"",
    "Add lease":"",
    "Add network":"",
    "Add placement options":"",
    "Admin":"",
    "Administrate":"",
    "Advanced mode":"",
    "Affected resources":"",
    "All":"",
    "Allowed operations":"",
    "Amount of RAM required for the VM, in Megabytes.":"",
    "Applies to":"",
    "Architecture":"",
    "are mandatory":"",
    "Arguments for the booting kernel":"",
    "Authentication":"",
    "Authentication driver":"",
    "Block":"",
    "Boolean expression that rules out provisioning hosts from list of machines suitable to run this VM":"",
    "Boot":"",
    "Boot device type":"",
    "Bootloader":"",
    "Boot method":"",
    "Boot/OS options":"",
    "Bridge":"",
    "Bus":"",
    "Cancel":"",
    "Cannot contact server: is it running and reachable?":"",
    "Canvas not supported.":"",
    "Capacity":"",
    "Capacity options":"",
    "cdrom":"",
    "CD-ROM":"",
    "Change":"",
    "Change authentication":"",
    "Change group":"",
    "Change owner":"",
    "Change password":"",
    "Changing language":"",
    "Clone":"",
    "Clone this image":"",
    "Community":"",
    "Configuration":"",
    "Confirmation of action":"",
    "Context":"",
    "Context variable name and value must be filled in":"",
    "Core":"",
    "CPU":"",
    "CPU architecture to virtualization":"",
    "CPU Monitoring information":"",
    "CPU Use":"",
    "Create":"",
    "Create ACL":"",
    "Create an empty datablock":"",
    "Create group":"",
    "Create host":"",
    "Create Image":"",
    "Create user":"",
    "Create Virtual Machine":"",
    "Create Virtual Network":"",
    "Create VM Template":"",
    "Current disks":"",
    "Current inputs":"",
    "Current leases":"",
    "Current NICs":"",
    "Current variables":"",
    "Custom attribute name and value must be filled in":"",
    "Custom attributes":"",
    "Custom variable name and value must be filled in":"",
    "Custom variables":"",
    "Dashboard":"",
    "Data":"",
    "Datablock":"",
    "Default":"",
    "Default (current image type)":"",
    "Define a subnet by IP range":"",
    "Delete":"",
    "Delete host":"",
    "Deploy":"",
    "Deploy ID":"",
    "Deploy # VMs":"",
    "Description":"",
    "Device prefix":"",
    "Device to be mounted as root":"",
    "Device to map image disk. If set, it will overwrite the default device mapping":"",
    "Disable":"",
    "disabled":"",
    "Disallow access to the VM through the specified ports in the TCP protocol":"",
    "Disallow access to the VM through the specified ports in the UDP protocol":"",
    "Disk":"",
    "Disk file location path or URL":"",
    "disk id":"",
    "Disks":"",
    "Disk type":"",
    "Documentation":"",
    "Do you want to proceed?":"",
    "Driver":"",
    "Driver default":"",
    "Drivers":"",
    "Drop":"",
    "Dummy":"",
    "EC2":"",
    "Enable":"",
    "English":"",
    "Error":"",
    "failed":"",
    "fd":"",
    "Features":"",
    "Fields marked with":"",
    "File":"",
    "Filesystem type":"",
    "Filesystem type for the fs images":"",
    "Fill in a new password":"",
    "Fixed network":"",
    "Floppy":"",
    "Fold / Unfold all sections":"",
    "Format":"",
    "FS":"",
    "FS type":"",
    "Graphics":"",
    "Graphics type":"",
    "Group":"",
    "Group ":"",
    "Group name":"",
    "Groups":"",
    "Hardware that will emulate this network interface. With Xen this is the type attribute of the vif.":"",
    "hd":"",
    "Historical monitoring information":"",
    "hold":"",
    "Hold":"",
    "Hold lease":"",
    "Host":"",
    "Host information":"",
    "Hostname":"",
    "Host name missing!":"",
    "Host parameters":"",
    "Hosts":"",
    "Hosts CPU":"",
    "Host shares":"",
    "Hosts memory":"",
    "Hosts (total/active)":"",
    "Host template":"",
    "Human readable description of the image for other users.":"",
    "HW address associated with the network interface":"",
    "Icmp":"",
    "ICMP policy":"",
    "id":"",
    "ID":"",
    "IDE":"",
    "Image":"",
    "Image information":"",
    "Image name":"",
    "Images":"",
    "Images (total/public)":"",
    "Image template":"",
    "IM MAD":"",
    "Info":"",
    "information":"",
    "Information":"",
    "Information Manager":"",
    "Initrd":"",
    "Inputs":"",
    "Instantiate":"",
    "IP":"",
    "IP End":"",
    "IP Start":"",
    "IP to listen on":"",
    "Kernel":"",
    "Kernel commands":"",
    "Keyboard configuration locale to use in the VNC display":"",
    "Keymap":"",
    "KVM":"",
    "Language":"",
    "LCM State":"",
    "Lease IP":"",
    "Lease MAC (opt):":"",
    "Lease management":"",
    "Leases information":"",
    "Listen IP":"",
    "Live migrate":"",
    "Loading":"",
    "Loading new language... please wait":"",
    "MAC":"",
    "Make non persistent":"",
    "Make persistent":"",
    "Manage":"",
    "Manual":"",
    "Max Mem":"",
    "Memory":"",
    "Memory monitoring information":"",
    "Memory use":"",
    "Migrate":"",
    "Model":"",
    "Monitoring information":"",
    "Mount image as read-only":"",
    "Mouse":"",
    "Name":"",
    "Name for the context variable":"",
    "Name for the custom variable":"",
    "Name for the tun device created for the VM":"",
    "Name of a shell script to be executed after creating the tun device for the VM":"",
    "Name of the bridge the network device is going to be attached to":"",
    "Name of the image to use":"",
    "Name of the network to attach this device":"",
    "Name that the Image will get. Every image must have a unique name.":"",
    "Name that the VM will get for description purposes. If NAME is not supplied a name generated by one will be in the form of one-&lt;VID&gt;.":"",
    "Net_RX":"",
    "Net_TX":"",
    "network":"",
    "Network":"",
    "Network Address":"",
    "Network is unreachable: is OpenNebula running?":"",
    "Network mask":"",
    "Network Mask":"",
    "Network reception":"",
    "Network transmission":"",
    "Network type":"",
    "New":"",
    "+ New":"",
    "+ New Group":"",
    "New password":"",
    "No":"",
    "No disk id or image name specified":"",
    "No disks defined":"",
    "No leases to show":"",
    "None":"",
    "Number of virtual cpus. This value is optional, the default hypervisor behavior is used, usually one virtual CPU.":"",
    "OK":"",
    "Open VNC Session":"",
    "Optional, please select":"",
    "OS":"",
    "OS and Boot options":"",
    "Other":"",
    "Owned by group":"",
    "Owner":"",
    "PAE":"",
    "Password":"",
    "Password for the VNC server":"",
    "Path":"",
    "Path to the bootloader executable":"",
    "Path to the initrd image":"",
    "Path to the original file that will be copied to the image repository. If not specified for a DATABLOCK type image, an empty image will be created.":"",
    "Path to the OS kernel to boot the image":"",
    "Path vs. source":"",
    "Percentage of CPU divided by 100 required for the Virtual Machine. Half a processor is written 0.5.":"",
    "Permissions":"",
    "Permits access to the VM only through the specified ports in the TCP protocol":"",
    "Permits access to the VM only through the specified ports in the UDP protocol":"",
    "Persistence of the image":"",
    "Persistent":"",
    "Physical address extension mode allows 32-bit guests to address more than 4 GB of memory":"",
    "Physical device":"",
    "Placement":"",
    "Please choose":"",
    "Please, choose and modify the image you want to update":"",
    "Please, choose and modify the template you want to update":"",
    "Please, choose and modify the virtual machine you want to update":"",
    "Please, choose and modify the virtual network you want to update":"",
    "Please choose path if you have a file-based image. Choose source otherwise or create an empty datablock disk.":"",
    "Please choose the new type of authentication for the selected users":"",
    "Please provide a lease IP":"",
    "Please provide a network address":"",
    "Please provide a resource ID for the resource(s) in this rule":"",
    "Please select":"",
    "Please select at least one resource":"",
    "Please specify to who this ACL applies":"",
    "Port":"",
    "Port blacklist":"",
    "Port for the VNC server":"",
    "Port whitelist":"",
    "Predefined":"",
    "Prefix for the emulated device this image will be mounted at. For instance, “hd”, “sd”. If omitted, the default value is the one defined in oned.conf (installation default is “hd”).":"",
    "Previous action":"",
    "Provide a path":"",
    "Provide a source":"",
    "PS2":"",
    "Public":"",
    "Publish":"",
    "Quickstart":"",
    "Ranged network":"",
    "Rank":"",
    "Raw":"",
    "Raw data to be passed directly to the hypervisor":"",
    "Read only":"",
    "Reboot":"",
    "Refresh list":"",
    "Register time":"",
    "Registration time":"",
    "release":"",
    "Release":"",
    "Remove selected":"",
    "Request an specific IP from the Network":"",
    "Requirements":"",
    "Reset":"",
    "Resource ID":"",
    "Resource ID / Owned by":"",
    "Resource subset":"",
    "Restart":"",
    "Resubmit":"",
    "Resume":"",
    "Retrieving":"",
    "Root":"",
    "running":"",
    "Running VMs":"",
    "Running #VMS":"",
    "Russian":"",
    "Save":"",
    "Save as":"",
    "Saveas for VM with ID":"",
    "Save this image after shutting down the VM":"",
    "Script":"",
    "SCSI":"",
    "SDL":"",
    "Select a network":"",
    "Select an image":"",
    "Select a template":"",
    "Select a VM":"",
    "Select boot method":"",
    "Select disk":"",
    "Select template":"",
    "Select the new group":"",
    "Select the new owner":"",
    "Server (Cipher)":"",
    "Server (x509)":"",
    "Setup Networks":"",
    "Shared":"",
    "Shutdown":"",
    "Sign out":"",
    "Size":"",
    "Size in MB":"",
    "Size (Mb)":"",
    "Size of the datablock in MB.":"",
    "Skipping VM ":"",
    "Source":"",
    "Source to be used in the DISK attribute. Useful for not file-based images.":"",
    "Specific ID":"",
    "Specific image mapping driver. KVM: raw, qcow2. XEN: tap:aio, file:":"",
    "Specific image mapping driver. KVM: raw, qcow2. Xen:tap:aio:, file:. VMware unsupported":"",
    "SSH":"",
    "Start time":"",
    "Start Time":"",
    "State":"",
    "Status":"",
    "Stop":"",
    "Submitted":"",
    "Summary of resources":"",
    "Sunstone UI Configuration":"",
    "Support":"",
    "Suspend":"",
    "Swap":"",
    "Tablet":"",
    "Target":"",
    "Tcp black ports":"",
    "Tcp firewall mode":"",
    "Tcp white ports":"",
    "Template":"",
    "Template information":"",
    "Templates":"",
    "Template updated correctly":"",
    "There are mandatory fields missing in the capacity section":"",
    "There are mandatory fields missing in the OS Boot options section":"",
    "There are mandatory parameters missing":"",
    "There are mandatory parameters missing in this section":"",
    "This field sets which attribute will be used to sort the suitable hosts for this VM. Basically, it defines which hosts are more suitable than others":"",
    "This rule applies to":"",
    "This will cancel selected VMs":"",
    "This will change the main group of the selected users. Select the new group":"",
    "This will change the password for the selected users":"",
    "This will delete the selected VMs from the database":"",
    "This will deploy the selected VMs on the chosen host":"",
    "This will hold selected pending VMs from being deployed":"",
    "This will initiate the shutdown process in the selected VMs":"",
    "This will live-migrate the selected VMs to the chosen host":"",
    "This will migrate the selected VMs to the chosen host":"",
    "This will redeploy selected VMs (in UNKNOWN or BOOT state)":"",
    "This will release held machines":"",
    "This will resubmits VMs to PENDING state":"",
    "This will resume selected stopped or suspended VMs":"",
    "This will send a reboot action to running VMs":"",
    "This will suspend selected machines":"",
    "TM MAD":"",
    "total":"",
    "Total Leases":"",
    "Total VM count":"",
    "Total VM CPU":"",
    "Total VM Memory":"",
    "Transfer Manager":"",
    "Type":"",
    "Type of disk device to emulate.":"",
    "Type of disk device to emulate: ide, scsi":"",
    "Type of file system to be built. This can be any value understood by mkfs unix command.":"",
    "Type of the image, explained in detail in the following section. If omitted, the default value is the one defined in oned.conf (install default is OS).":"",
    "Udp black ports":"",
    "Udp firewall mode":"",
    "Udp white ports":"",
    "Unauthorized":"",
    "Unpublish":"",
    "Update":"",
    "Update a template":"",
    "Update image properties":"",
    "Update network properties":"",
    "Update properties":"",
    "Update template":"",
    "Update template properties":"",
    "Update VM properties":"",
    "USB":"",
    "Use":"",
    "Used by VM":"",
    "Used CPU":"",
    "Used CPU (allocated)":"",
    "Used CPU (real)":"",
    "Used Mem (allocated)":"",
    "Used Memory":"",
    "Used Mem (real)":"",
    "Useful for power management, for example, normally required for graceful shutdown to work":"",
    "User":"",
    "User information":"",
    "Username":"",
    "User name and password must be filled in":"",
    "Users":"",
    "User template":"",
    "Value":"",
    "Value of the context variable":"",
    "Value of the custom variable":"",
    "VCPU":"",
    "Virtio":"",
    "Virtio (KVM)":"",
    "Virtualization Manager":"",
    "Virtual Machine information":"",
    "Virtual Machines":"",
    "Virtual Network":"",
    "Virtual network information":"",
    "Virtual Network information":"",
    "Virtual Network name missing!":"",
    "Virtual Networks":"",
    "Virtual Networks (total/public)":"",
    "Virtual Network template (attributes)":"",
    "VM information":"",
    "VM Instance":"",
    "VM Instances":"",
    "VM log":"",
    "VM MAD":"",
    "VM Name":"",
    "VM Network stats":"",
    "#VMS":"",
    "VM Save As":"",
    "VM template":"",
    "VM Template":"",
    "VM Templates":"",
    "VM Templates (total/public)":"",
    "VNC":"",
    "VNC Access":"",
    "VNC connection":"",
    "VNC Disabled":"",
    "VNC Session":"",
    "VNET ID":"",
    "VN MAD":"",
    "Welcome":"",
    "Wizard":"",
    "Wizard KVM":"",
    "Wizard VMware":"",
    "Wizard XEN":"",
    "Write the image template here":"",
    "Write the Virtual Machine template here":"",
    "Write the Virtual Network template here":"",
    "x509":"",
    "XEN":"",
    "Xen templates must specify a boot method":"",
    "yes":"",
    "Yes":"",
    "You have not selected a template":"",
    "You have to confirm this action.":"",
    "You need to select something.":"",
};

==> opennebula_3.4.1.orig.tar.gz: opennebula-3.4.1/src/sunstone/public/locale/en_US/en_US.js <==
//Translated by
lang="en_US"
datatable_lang=""
locale={
    "802.1Q":"",
    "Accept (default)":"",
    "ACL":"",
    "ACL Rules":"",
    "ACLs":"",
    "ACL String preview":"",
    "ACPI":"",
    "Add":"",
    "Add context variables":"",
    "Add custom variables":"",
    "Add disk/image":"",
    "Add disks/images":"",
    "Add Graphics":"",
    "Add Hypervisor raw options":"",
    "Add inputs":"",
    "Add lease":"",
    "Add network":"",
    "Add placement options":"",
    "Admin":"",
    "Administrate":"",
    "Advanced mode":"",
    "Affected resources":"",
    "All":"",
    "Allowed operations":"",
    "Amount of RAM required for the VM, in Megabytes.":"",
    "Applies to":"",
    "Architecture":"",
    "are mandatory":"",
    "Arguments for the booting kernel":"",
    "Authentication":"",
    "Authentication driver":"",
    "Base path":"",
    "Block":"",
    "Boolean expression that rules out provisioning hosts from list of machines suitable to run this VM":"",
    "Boot":"",
    "Boot device type":"",
    "Bootloader":"",
    "Boot method":"",
    "Boot/OS options":"",
    "Bridge":"",
    "Bus":"",
    "Cancel":"",
    "Cannot contact server: is it running and reachable?":"",
    "Canvas not supported.":"",
    "Capacity":"",
    "Capacity options":"",
    "cdrom":"",
    "CD-ROM":"",
    "Change":"",
    "Change authentication":"",
    "Change group":"",
    "Change owner":"",
    "Change password":"",
    "Change password successful":"",
    "Changing language":"",
    "Clone":"",
    "Clone this image":"",
    "Cluster":"",
    "Cluster information":"",
    "Cluster name missing!":"",
    "Clusters":"",
    "Community":"",
    "Configuration":"",
    "Confirmation of action":"",
    "Context":"",
    "Context variable name and value must be filled in":"",
    "Core":"",
    "CPU":"",
    "CPU architecture to virtualization":"",
    "CPU Monitoring information":"",
    "CPU Use":"",
    "Create":"",
    "Create ACL":"",
    "Create an empty datablock":"",
    "Create cluster":"",
    "Create Datastore":"",
    "Create group":"",
    "Create host":"",
    "Create Image":"",
    "Create new":"",
    "Create new ACL":"",
    "Create new Cluster":"",
    "Create new datastore":"",
    "Create new Datastore":"",
    "Create new Group":"",
    "Create new host":"",
    "Create new Host":"",
    "Create new Image":"",
    "Create new User":"",
    "Create new Virtual Machine":"",
    "Create new virtual network":"",
    "Create new Virtual Network":"",
    "Create new VM Template":"",
    "Create user":"",
    "Create Virtual Machine":"",
    "Create Virtual Network":"",
    "Create VM Template":"",
    "Current disks":"",
    "Current inputs":"",
    "Current leases":"",
    "Current NICs":"",
    "Current number of datastores in this cluster":"",
    "Current number of hosts in this cluster":"",
    "Current number of virtual networks in this cluster":"",
    "Current variables":"",
    "Custom attribute name and value must be filled in":"",
    "Custom attributes":"",
    "Custom variable name and value must be filled in":"",
    "Custom variables":"",
    "Dashboard":"",
    "Data":"",
    "Datablock":"",
    "Datastore":"",
    "Datastore information":"",
    "Datastore manager":"",
    "Datastores":"",
    "Datastore template":"",
    "Datastore Template":"",
    "Datastore updated correctly":"",
    "Default":"",
    "Default (current image type)":"",
    "Default (dummy)":"",
    "Defaults to template name when emtpy":"",
    "Define a subnet by IP range":"",
    "Delete":"",
    "Delete host":"",
    "Deploy":"",
    "Deploy ID":"",
    "Deploy # VMs":"",
    "Description":"",
    "Device prefix":"",
    "Device to be mounted as root":"",
    "Device to map image disk. If set, it will overwrite the default device mapping":"",
    "Disable":"",
    "disabled":"",
    "Disallow access to the VM through the specified ports in the TCP protocol":"",
    "Disallow access to the VM through the specified ports in the UDP protocol":"",
    "Disk":"",
    "Disk file location path or URL":"",
    "disk id":"",
    "Disks":"",
    "Disk type":"",
    "Documentation":"",
    "Do you want to proceed?":"",
    "Driver":"",
    "Driver default":"",
    "Drivers":"",
    "Drop":"",
    "DS Mad":"",
    "Dummy":"",
    "EC2":"",
    "Enable":"",
    "English":"",
    "Error":"",
    "Etables":"",
    "failed":"",
    "fd":"",
    "Features":"",
    "Fields marked with":"",
    "File":"",
    "Filesystem":"",
    "Filesystem type":"",
    "Filesystem type for the fs images":"",
    "Fill in a new password":"",
    "Fixed network":"",
    "Floppy":"",
    "Fold / Unfold all sections":"",
    "Format":"",
    "FS":"",
    "FS type":"",
    "Graphics":"",
    "Graphics type":"",
    "Group":"",
    "Group ":"",
    "Group name":"",
    "Groups":"",
    "Hardware that will emulate this network interface. With Xen this is the type attribute of the vif.":"",
    "hd":"",
    "Historical monitoring information":"",
    "History information":"",
    "hold":"",
    "Hold":"",
    "Hold lease":"",
    "Host":"",
    "Host information":"",
    "Hostname":"",
    "Host name missing!":"",
    "Host parameters":"",
    "Hosts":"",
    "Hosts CPU":"",
    "Host shares":"",
    "Hosts memory":"",
    "Hosts (total/active)":"",
    "Host template":"",
    "Human readable description of the image for other users.":"",
    "HW address associated with the network interface":"",
    "Icmp":"",
    "ICMP policy":"",
    "id":"",
    "ID":"",
    "IDE":"",
    "Image":"",
    "Image information":"",
    "Image location":"",
    "Image name":"",
    "Images":"",
    "Image template":"",
    "Image updated correctly":"",
    "IM MAD":"",
    "Info":"",
    "information":"",
    "Information":"",
    "Information Manager":"",
    "Infrastructure":"",
    "Infrastructure resources":"",
    "Initrd":"",
    "Inputs":"",
    "Instantiate":"",
    "IP":"",
    "IP End":"",
    "IPs":"",
    "IP Start":"",
    "IP to listen on":"",
    "iSCSI":"",
    "Italian":"",
    "Kernel":"",
    "Kernel commands":"",
    "Keyboard configuration locale to use in the VNC display":"",
    "Keymap":"",
    "KVM":"",
    "Language":"",
    "LCM State":"",
    "Lease IP":"",
    "Lease MAC (opt):":"",
    "Lease management":"",
    "Leases information":"",
    "Listen IP":"",
    "Live migrate":"",
    "Loading":"",
    "Loading new language... please wait":"",
    "MAC":"",
    "Make non persistent":"",
    "Make persistent":"",
    "Manage":"",
    "Manage cluster datastores":"",
    "Manage cluster hosts":"",
    "Manage cluster virtual networks":"",
    "Manage unclustered datastores":"",
    "Manage unclustered hosts":"",
    "Manage unclustered virtual networks":"",
    "Manual":"",
    "Max Mem":"",
    "Memory":"",
    "Memory monitoring information":"",
    "Memory use":"",
    "Migrate":"",
    "Model":"",
    "Monitoring information":"",
    "Mount image as read-only":"",
    "Mouse":"",
    "Name":"",
    "Name for the context variable":"",
    "Name for the custom variable":"",
    "Name for the tun device created for the VM":"",
    "Name of a shell script to be executed after creating the tun device for the VM":"",
    "Name of the bridge the network device is going to be attached to":"",
    "Name of the image to use":"",
    "Name of the network to attach this device":"",
    "Name that the Image will get. Every image must have a unique name.":"",
    "Name that the VM will get for description purposes. If NAME is not supplied a name generated by one will be in the form of one-&lt;VID&gt;.":"",
    "Net_RX":"",
    "Net_TX":"",
    "network":"",
    "Network":"",
    "Network Address":"",
    "Network is unreachable: is OpenNebula running?":"",
    "Network mask":"",
    "Network Mask":"",
    "Network mode":"",
    "Network reception":"",
    "Network transmission":"",
    "Network type":"",
    "+ New":"",
    "+ New Group":"",
    "New password":"",
    "No":"",
    "No datastores in this cluster":"",
    "No disk id or image name specified":"",
    "No disks defined":"",
    "No hosts in this cluster":"",
    "No leases to show":"",
    "None":"",
    "No virtual networks in this cluster":"",
    "Number of virtual cpus. This value is optional, the default hypervisor behavior is used, usually one virtual CPU.":"",
    "OK":"",
    "Open VNC Session":"",
    "Open vSwitch":"",
    "Optional, please select":"",
    "OS":"",
    "OS and Boot options":"",
    "Other":"",
    "Owned by group":"",
    "Owner":"",
    "PAE":"",
    "Password":"",
    "Password for the VNC server":"",
    "Path":"",
    "Path to the bootloader executable":"",
    "Path to the initrd image":"",
    "Path to the original file that will be copied to the image repository. If not specified for a DATABLOCK type image, an empty image will be created.":"",
    "Path to the OS kernel to boot the image":"",
    "Percentage of CPU divided by 100 required for the Virtual Machine. Half a processor is written 0.5.":"",
    "Permissions":"",
    "Permits access to the VM only through the specified ports in the TCP protocol":"",
    "Permits access to the VM only through the specified ports in the UDP protocol":"",
    "Persistence of the image":"",
    "Persistent":"",
    "Physical address extension mode allows 32-bit guests to address more than 4 GB of memory":"",
    "Physical device":"",
    "Placement":"",
    "Please choose":"",
    "Please, choose and modify the datastore you want to update":"",
    "Please, choose and modify the image you want to update":"",
    "Please, choose and modify the template you want to update":"",
    "Please, choose and modify the virtual machine you want to update":"",
    "Please, choose and modify the virtual network you want to update":"",
    "Please choose path if you have a file-based image. Choose source otherwise or create an empty datablock disk.":"",
    "Please choose the new type of authentication for the selected users":"",
    "Please provide a lease IP":"",
    "Please provide a resource ID for the resource(s) in this rule":"",
    "Please select":"",
    "Please select a datastore for this image":"",
    "Please select at least one resource":"",
    "Please specify to who this ACL applies":"",
    "Port":"",
    "Port blacklist":"",
    "Port for the VNC server":"",
    "Port whitelist":"",
    "Predefined":"",
    "Prefix for the emulated device this image will be mounted at. For instance, “hd”, “sd”. If omitted, the default value is the one defined in oned.conf (installation default is “hd”).":"",
    "Previous action":"",
    "Prolog time":"",
    "Provide a path":"",
    "Provide a source":"",
    "PS2":"",
    "Public":"",
    "Quickstart":"",
    "Ranged network":"",
    "Rank":"",
    "Raw":"",
    "Raw data to be passed directly to the hypervisor":"",
    "Read only":"",
    "Reason":"",
    "Reboot":"",
    "Refresh list":"",
    "Register time":"",
    "Registration time":"",
    "release":"",
    "Release":"",
    "Remove selected":"",
    "Request an specific IP from the Network":"",
    "Requirements":"",
    "Reset":"",
    "Resource ID":"",
    "Resource ID / Owned by":"",
    "Resource subset":"",
    "Restart":"",
    "Resubmit":"",
    "Resume":"",
    "Retrieving":"",
    "Root":"",
    "running":"",
    "Running VMs":"",
    "Running #VMS":"",
    "Russian":"",
    "Save":"",
    "Save as":"",
    "Saveas for VM with ID":"",
    "Save this image after shutting down the VM":"",
    "Script":"",
    "SCSI":"",
    "SDL":"",
    "Secure websockets connection":"",
    "Select a datastore":"",
    "Select a network":"",
    "Select an image":"",
    "Select a template":"",
    "Select a VM":"",
    "Select boot method":"",
    "Select cluster":"",
    "Select disk":"",
    "Select template":"",
    "Select the datastore for this image":"",
    "Select the destination cluster:":"",
    "Select the new group":"",
    "Select the new owner":"",
    "Sequence":"",
    "Server (Cipher)":"",
    "Server (x509)":"",
    "Setup Networks":"",
    "Shared":"",
    "shared,ssh,iscsi,dummy":"",
    "Shutdown":"",
    "Sign out":"",
    "Size":"",
    "Size in MB":"",
    "Size (Mb)":"",
    "Size of the datablock in MB.":"",
    "Skipping VM ":"",
    "Source":"",
    "Source to be used in the DISK attribute. Useful for not file-based images.":"",
    "Specific ID":"",
    "Specific image mapping driver. KVM: raw, qcow2. XEN: tap:aio, file:":"",
    "Specific image mapping driver. KVM: raw, qcow2. Xen:tap:aio:, file:. VMware unsupported":"",
    "SSH":"",
    "Start time":"",
    "Start Time":"",
    "State":"",
    "State change time":"",
    "Status":"",
    "Stop":"",
    "style":"",
    "Submitted":"",
    "Summary of infrastructure resources":"",
    "Summary of resources":"",
    "Summary of system resources":"",
    "Summary of virtual resources":"",
    "Sunstone UI Configuration":"",
    "Support":"",
    "Suspend":"",
    "Swap":"",
    "System":"",
    "System Resources":"",
    "System resources management is only accesible to users of the oneadmin group. It comprises the operations regarding OpenNebula groups, users and ACLs.":"",
    "Tablet":"",
    "Target":"",
    "Tcp black ports":"",
    "Tcp firewall mode":"",
    "Tcp white ports":"",
    "Template":"",
    "Template information":"",
    "Templates":"",
    "Template updated correctly":"",
    "The Infrastructure menu allows management of Hosts, Datastores, Virtual Networks. Users in the oneadmin group can manage clusters as well.":"",
    "There are mandatory fields missing in the capacity section":"",
    "There are mandatory fields missing in the OS Boot options section":"",
    "There are mandatory parameters missing":"",
    "There are mandatory parameters missing in this section":"",
    "There are missing network parameters":"",
    "The Virtual Resources menu allows management of Virtual Machine Templates, Instances and Images.":"",
    "This field sets which attribute will be used to sort the suitable hosts for this VM. Basically, it defines which hosts are more suitable than others":"",
    "This rule applies to":"",
    "This will cancel selected VMs":"",
    "This will change the main group of the selected users. Select the new group":"",
    "This will change the password for the selected users":"",
    "This will delete the selected VMs from the database":"",
    "This will deploy the selected VMs on the chosen host":"",
    "This will hold selected pending VMs from being deployed":"",
    "This will initiate the shutdown process in the selected VMs":"",
    "This will live-migrate the selected VMs to the chosen host":"",
    "This will migrate the selected VMs to the chosen host":"",
    "This will redeploy selected VMs (in UNKNOWN or BOOT state)":"",
    "This will release held machines":"",
    "This will resubmits VMs to PENDING state":"",
    "This will resume selected stopped or suspended VMs":"",
    "This will send a reboot action to running VMs":"",
    "This will suspend selected machines":"",
    "TM Mad":"",
    "TM MAD":"",
    "total":"",
    "Total Leases":"",
    "Total time":"",
    "Total VM count":"",
    "Total VM CPU":"",
    "Total VM Memory":"",
    "Transfer manager":"",
    "Transfer Manager":"",
    "Type":"",
    "Type of disk device to emulate.":"",
    "Type of disk device to emulate: ide, scsi":"",
    "Type of file system to be built. This can be any value understood by mkfs unix command.":"",
    "Type of the image, explained in detail in the following section. If omitted, the default value is the one defined in oned.conf (install default is OS).":"",
    "Udp black ports":"",
    "Udp firewall mode":"",
    "Udp white ports":"",
    "Unauthorized":"",
    "Update":"",
    "Update a template":"",
    "Update Datastore properties":"",
    "Update image properties":"",
    "Update network properties":"",
    "Update properties":"",
    "Update template":"",
    "Update template properties":"",
    "Update VM properties":"",
    "Upload":"",
    "Upload file":"",
    "Uploading...":"",
    "USB":"",
    "Use":"",
    "Used by VM":"",
    "Used CPU":"",
    "Used CPU (allocated)":"",
    "Used CPU (real)":"",
    "Used Mem (allocated)":"",
    "Used Memory":"",
    "Used Mem (real)":"",
    "Useful for power management, for example, normally required for graceful shutdown to work":"",
    "User":"",
    "User information":"",
    "Username":"",
    "User name and password must be filled in":"",
    "Users":"",
    "User template":"",
    "Value":"",
    "Value of the context variable":"",
    "Value of the custom variable":"",
    "VCPU":"",
    "Virtio":"",
    "Virtio (KVM)":"",
    "Virtualization Manager":"",
    "Virtual Machine information":"",
    "Virtual Machines":"",
    "Virtual Network":"",
    "Virtual network information":"",
    "Virtual Network information":"",
    "Virtual Network name missing!":"",
    "Virtual Networks":"",
    "Virtual Network template (attributes)":"",
    "Virtual Resources":"",
    "VLAN":"",
    "VLAN ID":"",
    "VM information":"",
    "VM Instance":"",
    "VM Instances":"",
    "VM log":"",
    "VM MAD":"",
    "VM Name":"",
    "VM Network stats":"",
    "#VMS":"",
    "VM Save As":"",
    "VM template":"",
    "VM Template":"",
    "VM Templates":"",
    "VMware":"",
    "VNC":"",
    "VNC Access":"",
    "VNC connection":"",
    "VNC Disabled":"",
    "VNC Session":"",
    "VN MAD":"",
    "Welcome":"",
    "Wizard":"",
    "Wizard KVM":"",
    "Wizard VMware":"",
    "Wizard XEN":"",
    "Write the image template here":"",
    "Write the Virtual Machine template here":"",
    "Write the Virtual Network template here":"",
    "x509":"",
    "XEN":"",
    "Xen templates must specify a boot method":"",
    "yes":"",
    "Yes":"",
    "You can find further information on the following links:":"",
    "You can use the wildcard %i. When creating several VMs, %i will be replaced with a different number starting from 0 in each of them":"",
    "You have not selected a template":"",
    "You have to confirm this action.":"",
    "You need to select something.":"",
};
